#[repr(u8)]pub enum WitnessScope {
None = 0,
CalledByEntry = 1,
CustomContracts = 16,
CustomGroups = 32,
WitnessRules = 64,
Global = 128,
}Variants
Implementations
Sourceimpl WitnessScope
impl WitnessScope
pub fn byte_repr(&self) -> u8
Sourcepub fn validate(scopes: &[WitnessScope]) -> Result<(), BuilderError>
pub fn validate(scopes: &[WitnessScope]) -> Result<(), BuilderError>
Validates that scope combinations are legal per Neo N3 protocol. Global and None scopes must not be combined with any other scope.
pub fn combine(scopes: &[Self]) -> u8
pub fn split(flags: u8) -> Vec<Self>