pub struct InvocationScript { /* private fields */ }Expand description
An invocation script is part of a witness and is simply a sequence of neo-vm instructions.
The invocation script usually is the input to the verification script.
In most cases it will contain a signature that is checked in the verification script.
Implementations
Sourceimpl InvocationScript
impl InvocationScript
Sourcepub fn set_script(&mut self, val: Vec<u8>) -> &mut Self
pub fn set_script(&mut self, val: Vec<u8>) -> &mut Self
This invocation script as a byte array
Sourceimpl InvocationScript
impl InvocationScript
Sourcepub fn new_with_script(script: Vec<u8>) -> Self
pub fn new_with_script(script: Vec<u8>) -> Self
Creates an invocation script with the given script.
It is recommended to use InvocationScript::from_signature or InvocationScript::from_message_and_key_pair
when you need a signature invocation script.
Arguments
script- The script as a byte array
pub fn from_serialized_script(script: Vec<u8>) -> Self
Sourcepub fn from_signature(signature: Secp256r1Signature) -> Self
pub fn from_signature(signature: Secp256r1Signature) -> Self
Sourcepub fn from_message_and_key_pair(
message: Vec<u8>,
key_pair: &KeyPair,
) -> Result<Self, BuilderError>
pub fn from_message_and_key_pair( message: Vec<u8>, key_pair: &KeyPair, ) -> Result<Self, BuilderError>
Sourcepub fn from_signatures(signatures: &[Secp256r1Signature]) -> Self
pub fn from_signatures(signatures: &[Secp256r1Signature]) -> Self
pub fn try_encode(&self, writer: &mut Encoder) -> Result<(), BuilderError>
pub fn try_to_array(&self) -> Result<Vec<u8>, BuilderError>
Sourceimpl InvocationScript
impl InvocationScript
Sourcepub fn get_signatures(&self) -> Vec<Secp256r1Signature>
pub fn get_signatures(&self) -> Vec<Secp256r1Signature>
Unbundles the script into a list of signatures if this invocation script contains signatures.
Returns
The list of signatures found in this script