#[non_exhaustive]pub enum ContractError {
Show 16 variants
InvalidNeoName(String),
InvalidNeoNameServiceRoot(String),
UnexpectedReturnType(String),
UnresolvableDomainName(String),
DomainNameNotAvailable(String),
DomainNameNotRegistered(String),
UnsupportedOperation(String),
RuntimeError(String),
InvalidStateError(String),
InvalidArgError(String),
ProviderError(ProviderError),
ProviderNotSet(String),
InvocationFailed(String),
InvalidResponse(String),
InvalidAccount(String),
InvalidScriptHash(String),
}Expand description
Custom error type for contract-related errors
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidNeoName(String)
Error indicating an invalid Neo name
InvalidNeoNameServiceRoot(String)
Error indicating an invalid Neo Name Service root
UnexpectedReturnType(String)
Error indicating an unexpected return type
UnresolvableDomainName(String)
Error indicating an unresolvable domain name
DomainNameNotAvailable(String)
Error indicating that a domain name is not available
DomainNameNotRegistered(String)
Error indicating that a domain name is not registered
UnsupportedOperation(String)
Error indicating an unsupported operation
RuntimeError(String)
Error indicating a runtime error
InvalidStateError(String)
Error indicating an invalid state error
InvalidArgError(String)
Error indicating an invalid argument error
ProviderError(ProviderError)
Error indicating a provider error, transparently wrapped
ProviderNotSet(String)
Error indicating that a provider is not set
InvocationFailed(String)
Error indicating that an invocation failed
InvalidResponse(String)
Error indicating an invalid response
InvalidAccount(String)
Error indicating an invalid account
InvalidScriptHash(String)
Error indicating an invalid script hash