pub enum AddressOrScriptHash {
Address(Address),
ScriptHash(H160),
}Expand description
An enum that can represent either a blockchain Address or a ScriptHash,
offering flexibility for APIs that can work with either.
Variants
Implementations
Sourceimpl AddressOrScriptHash
impl AddressOrScriptHash
Sourcepub fn try_from_script_hash_bytes(bytes: &[u8]) -> Result<Self, TypeError>
pub fn try_from_script_hash_bytes(bytes: &[u8]) -> Result<Self, TypeError>
Creates an AddressOrScriptHash from script hash bytes, rejecting invalid lengths.
Sourcepub fn address(&self) -> Address
pub fn address(&self) -> Address
Retrieves the Address representation. If the instance is a ScriptHash, converts it to an Address.
Examples
use primitive_types::H160;
use neo3::neo_types::AddressOrScriptHash;
let script_hash = AddressOrScriptHash::ScriptHash(H160::repeat_byte(0x01));
let address = script_hash.address();
// The address will be a valid Neo address derived from the script hash
assert!(address.starts_with("N"));Sourcepub fn try_script_hash(&self) -> Result<H160, TypeError>
pub fn try_script_hash(&self) -> Result<H160, TypeError>
Retrieves the ScriptHash representation. If the instance is an Address, converts it to a ScriptHash.
Errors
Returns TypeError::InvalidAddress when the stored address is invalid.
Sourcepub fn script_hash(&self) -> H160
pub fn script_hash(&self) -> H160
Retrieves the ScriptHash representation. If the instance is an Address, converts it to a ScriptHash.
Examples
use primitive_types::H160;
use neo3::neo_types::AddressOrScriptHash;
let address = AddressOrScriptHash::Address("NNLi44dJNXtDNSBkofB48aTVYtb1zZrNEs".to_string());
let script_hash = address.script_hash();
// The script hash will be derived from the address
assert!(script_hash != H160::zero());Trait Implementations
Sourceimpl Clone for AddressOrScriptHash
impl Clone for AddressOrScriptHash
Sourcefn clone(&self) -> AddressOrScriptHash
fn clone(&self) -> AddressOrScriptHash
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AddressOrScriptHash
impl Debug for AddressOrScriptHash
Sourceimpl Default for AddressOrScriptHash
impl Default for AddressOrScriptHash
Sourceimpl<'de> Deserialize<'de> for AddressOrScriptHash
impl<'de> Deserialize<'de> for AddressOrScriptHash
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Sourceimpl From<String> for AddressOrScriptHash
impl From<String> for AddressOrScriptHash
Sourcefn from(s: Address) -> Self
fn from(s: Address) -> Self
Allows creating an AddressOrScriptHash directly from an Address.
Examples
use neo3::neo_types::AddressOrScriptHash;
let from_address = AddressOrScriptHash::from("NNLi44dJNXtDNSBkofB48aTVYtb1zZrNEs".to_string());
assert!(matches!(from_address, AddressOrScriptHash::Address(_)));Sourceimpl From<Vec<u8>> for AddressOrScriptHash
impl From<Vec<u8>> for AddressOrScriptHash
Sourcefn from(s: Bytes) -> Self
fn from(s: Bytes) -> Self
Allows creating an AddressOrScriptHash from a Bytes array, automatically converting it into a ScriptHash.
Examples
use neo3::neo_types::{AddressOrScriptHash, Bytes};
let bytes: Bytes = vec![0xde, 0xad, 0xbe, 0xef, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b, 0x0c, 0x0d, 0x0e, 0x0f, 0x10];
let from_bytes = AddressOrScriptHash::from(bytes);
assert!(matches!(from_bytes, AddressOrScriptHash::ScriptHash(_)));Sourceimpl Hash for AddressOrScriptHash
impl Hash for AddressOrScriptHash
Sourcefn hash<H: Hasher>(&self, state: &mut H)
fn hash<H: Hasher>(&self, state: &mut H)
Implements the Hash trait to allow AddressOrScriptHash
instances to be used as keys in hash maps or elements in hash sets.
Examples
use std::collections::HashSet;
use neo3::neo_types::AddressOrScriptHash;
let mut set = HashSet::new();
set.insert(AddressOrScriptHash::Address("myAddress".into()));Sourceimpl PartialEq for AddressOrScriptHash
impl PartialEq for AddressOrScriptHash
Sourcefn eq(&self, other: &AddressOrScriptHash) -> bool
fn eq(&self, other: &AddressOrScriptHash) -> bool
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AddressOrScriptHash
impl Serialize for AddressOrScriptHash
Sourceimpl TryFrom<&[u8]> for AddressOrScriptHash
impl TryFrom<&[u8]> for AddressOrScriptHash
impl Eq for AddressOrScriptHash
impl StructuralPartialEq for AddressOrScriptHash